class ThuisbezorgdApiError(Exception):
    pass


class ThuisbezorgdAuthError(Exception):
    pass


class ThuisbezorgdTokenFileError(Exception):
    pass


class ThuisbezorgdCliDBError(Exception):
    pass
